@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import itertools
 import operator
 import re
@@ -6,10 +5,10 @@ from collections.abc import Mapping, Set
 from functools import lru_cache, reduce
 
 import attr
-import distlib.markers
-from packaging.markers import InvalidMarker, Marker
-from packaging.specifiers import LegacySpecifier, Specifier, SpecifierSet
-from packaging.version import parse
+from distlib import markers
+from pip._vendor.packaging.markers import InvalidMarker, Marker
+from pip._vendor.packaging.specifiers import LegacySpecifier, Specifier, SpecifierSet
+from pip._vendor.packaging.version import parse
 from vistir.misc import dedup
 
 from ..environment import MYPY_RUNNING
@@ -489,7 +488,7 @@ def _markers_contains_key(markers, key):
 def get_contained_extras(marker):
     """Collect "extra == ..." operands from a marker.
 
-    Returns a list of str. Each str is a speficied extra in this marker.
+    Returns a list of str. Each str is a specified extra in this marker.
     """
     if not marker:
         return set()
@@ -514,7 +513,7 @@ def get_contained_pyversions(marker):
         return set()
     # Use the distlib dictionary parser to create a dictionary 'trie' which is a bit
     # easier to reason about
-    marker_dict = distlib.markers.parse_marker(marker_str)[0]
+    marker_dict = markers.parse_marker(marker_str)[0]
     version_set = set()
     pyversions, _ = parse_marker_dict(marker_dict)
     if isinstance(pyversions, set):
@@ -532,7 +531,7 @@ def get_contained_pyversions(marker):
 
 @lru_cache(maxsize=128)
 def contains_extra(marker):
-    """Check whehter a marker contains an "extra == ..." operand."""
+    """Check whether a marker contains an "extra == ..." operand."""
     if not marker:
         return False
     marker = _ensure_marker(marker)
